==> bellsoft-jdk21.0.9+11-src-full.tar.gz: jdk-21.0.9-full/openjfx/modules/javafx.base/src/test/java/test/javafx/beans/property/PropertyReferenceWithInterfacesTest.java <==
/*
 * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package test.javafx.beans.property;

import javafx.beans.property.StringProperty;

import org.junit.Before;
import org.junit.Test;

import com.sun.javafx.property.PropertyReference;
import javafx.beans.property.SimpleStringProperty;
import static org.junit.Assert.*;

/**
 *
 */
public class PropertyReferenceWithInterfacesTest {

    @Before public void setUp() {

    }

    @Test public void shouldBeAbleToReadPropertyValueFromPropertyReferenceDeclaredOnInterface() {
        NamedBean test = new NamedBean();
        test.setName("A");
        assertEquals("A", test.getName());
        assertEquals("A", Named.NAME.get(test));
    }

    public interface Named {
        public static final PropertyReference<String> NAME = new PropertyReference<>(Named.class, "name");
        public String getName();
    }

    public static class NamedBean implements Named {
        private final StringProperty name = new SimpleStringProperty();
        @Override public final String getName() {return name.get();}
        public final void setName(String value) {name.set(value);}
    }
}

==> bellsoft-jdk25.0.2+12-src-full.tar.gz: jdk-25.0.2-full/openjfx/modules/javafx.base/src/test/java/test/javafx/beans/property/PropertyReferenceWithInterfacesTest.java <==
/*
 * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package test.javafx.beans.property;

import javafx.beans.property.StringProperty;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import com.sun.javafx.property.PropertyReference;
import javafx.beans.property.SimpleStringProperty;
import static org.junit.jupiter.api.Assertions.*;

/**
 *
 */
public class PropertyReferenceWithInterfacesTest {

    @BeforeEach public void setUp() {

    }

    @Test public void shouldBeAbleToReadPropertyValueFromPropertyReferenceDeclaredOnInterface() {
        NamedBean test = new NamedBean();
        test.setName("A");
        assertEquals("A", test.getName());
        assertEquals("A", Named.NAME.get(test));
    }

    public interface Named {
        public static final PropertyReference<String> NAME = new PropertyReference<>(Named.class, "name");
        public String getName();
    }

    public static class NamedBean implements Named {
        private final StringProperty name = new SimpleStringProperty();
        @Override public final String getName() {return name.get();}
        public final void setName(String value) {name.set(value);}
    }
}
